@@ -30,14 +30,28 @@ Unpack this distribution next to unpacked GD distribution. Then run
 
 You will be prompted for a directory containing the untarred GD
 distribution. Then the files containing the fonts are replaced with
-those with ISO-8859-2. Also, one minor patch is aplied to the libgd.c
-in order to make it 8-bit clean. And, the fifth test output gif (that
-contains some texts) is also replaced, so that the tests run OK.
+those with ISO-8859-2. Also, libgd.c and gd.h files are patched to make
+them 8-bit clean. And, the fifth test output gif (that contains some
+texts) is also replaced, so that the tests run OK.
 
 You can of course do all this by hand: the fonts are in the fonts
 directory, you should copy them into the libgd directory in GD
-distribution. Then apply the patch in file libgd.diff to libgd.c file
-in GD distribution.
+distribution, in Un*x using command like
+
+	cp fonts/* ../GD-1.16/libgd
+
+assuming you are chdir'd in the GD-Latin2 directory and the GD
+distribution is unpacked next to it (in ../GD-1.16).
+
+Then apply the patches in file libgd.c.diff to libgd.c and that in
+gd.h.diff to gd.h file in GD distribution. The Un*x command using the
+program patch would be like
+
+	patch -d ..GD-1.16/libgd < libgd.c.diff	
+	patch -d ..GD-1.16/libgd < gd.h.diff	
+
+You can of course change the relevant files by hand, change the lines
+in the diff files marked by !.
 
 =head1 OTHER CHARSETS
 
@@ -55,10 +69,28 @@ The small font has changed from 6x12 to 6x13 in ISO-8859-2 version.
 The bdftogd convertor is really a simple hack that suits my needs. You
 are welcome to find problems and send me patches to make it more general.
 
-=head1 VERSION
+=head1 CHANGES
+
+0.53
+
+Bug with "Up" characters fixed, spotted by Michal Brandejs. This
+resulted in a change in function prototype in libgd.c and also in
+gd.h, because eight bit characters cannot be treated as signed. We
+need to have them either as ints or as unsigned chars.
 
 0.51
 
+Better font found for 5x8, also the Giant font generated.
+
+0.5
+
+First release, put on CPAN; Lincoln Stein responds by saying he wants
+to apply the patch directly into the GD package.
+
+=head1 VERSION
+
+0.53
+
 =head1 AUTHOR
 
 Jan Pazdziora, adelton@fi.muni.cz
